#
# spec file for package ghc-tar
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name tar
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.5.1.1
Release:        bp154.2.12
Summary:        Reading, writing and manipulating ".tar" archive files
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/4.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-bytestring-handle-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
This library is for working with "'.tar'" archive files. It can read and write
a range of common variations of archive format including V7, POSIX USTAR and
GNU formats.

It provides support for packing and unpacking portable archives. This makes it
suitable for distribution but not backup because details like file ownership
and exact permissions are not preserved.

It also provides features for random access to archive content using an index.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc changelog.md

%changelog
* Tue Sep  7 2021 psimons@suse.com
- Update tar to version 0.5.1.1 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Feb 20 2021 psimons@suse.com
- Update tar to version 0.5.1.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update tar to version 0.5.1.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Aug 27 2019 psimons@suse.com
- Update tar to version 0.5.1.1.
  See also http://pvp.haskell.org/faq
  0.5.1.1 Herbert Valerio Riedel <hvr@gnu.org> March 2018
  * Add support for GHC 8.8.1 / base-4.13
* Fri Oct 19 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support ghc-8.6.1.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update tar to version 0.5.1.0.
  * Add support for GHC 8.4.1 / base-4.11
  * Add `Semigroup` instance for `Entries`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.5.0.3 revision 0 with cabal2obs.
* Wed May  4 2016 mimi.vx@gmail.com
- update to 0.5.0.3
  * Fix tarbomb logic to ignore special PAX entries. Was breaking many valid tarballs.
* Sun May  1 2016 mimi.vx@gmail.com
- update to 0.5.0.2
  * Fix compatability when using ghc-7.4.x and directory >= 1.2.3
* Fri Jan 15 2016 mimi.vx@gmail.com
- update to 0.5.0.1
  * Change type of Index.serialise to be simply strict bytestring.
  * Preserve file timestamps on unpack
* Mon Jan 11 2016 mimi.vx@gmail.com
- update to 0.4.5.0
  * revert accidental minor API change in 0.4.x series (the type of the owner and
    group name strings). The 0.4.3.0 and 0.4.4.0 releases contained the accidental
    API change.
  * Add a handy foldlEntries function
  * Build and warning fixes for GHC 7.10 and 8.0
  * New Index module function toList to get all index entries
  * New Index function unfinalise to extend existing index
    + 9x faster reading
    + 9x faster index construction
    + 24x faster index extension
  * More compact entry types, using ByteStrings
  * More Eq and Show instances
  * Greater QC test coverage
  * Fix minor bug in reading non-standard v7 format entries
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
